==> mdm-rpc-0.1.72-sources.jar: com/chinayanghe/msp/mdm/vo/productSale/ProductSaleVo.java <==
package com.chinayanghe.msp.mdm.vo.productSale;


import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 商品信息实体类
 */

public class ProductSaleVo  implements Serializable {


    private static final long serialVersionUID = 679916831294067386L;
    private String id;


    /**
     *商品编码
     */
    private String productSaleCode;
    /**
     *物料名称
     */
    private String materielName;
    /**
     * 产品组编码
     */
    private String spartCode;
    /**
     * 产品组名称
     */
    private String spartName;
    /**
     *基本计量单位编码
     */
    private String basicUnitCode;
    /**
     *基本计量单位名称
     */
    private String basicUnitName;
    /**
     *品类编码
     */
    private String productTypeCode;
    /**
     *品类描述
     */
    private String productTypeDesc;
    /**
     *品牌编码
     */
    private String productBrandCode;
    /**
     *品牌描述
     */
    private String productBrandDesc;
    /**
     *系列编码
     */
    private String seriesCode;
    /**
     *系列描述
     */
    private String seriesDesc;
    /**
     *大类编码
     */
    private String bigLevelCode;
    /**
     *大类描述
     */
    private String bigLevelDesc;
    /**
     *小类编码
     */
    private String smallLevelCode;
    /**
     *小类描述
     */
    private String smallLevelDesc;
    /**
     *渠道编码
     */
    private String channel;
    /**
     *渠道描述
     */
    private String channelDesc;
    /**
     *体积
     */
    private Double volume;
    /**
     *体积单位编码
     */
    private String volumeUnitCode;
    /**
     *体积单位名称
     */
    private String volumeUnitName;
    /**
     *大小/量纲(规格)
     */
    private String productSize;
    /**
     *外观色系编码
     */
    private String productExteriorCode;
    /**
     *外观色系名称
     */
    private String productExteriorName;
    /**
     *套装编码
     */
    private String suitCode;
    /**
     *套装名称
     */
    private String suitName;
    /**
     *商品执行标准编码
     */
    private String executionStandardCode;
    /**
     *商品执行标准名称
     */
    private String executionStandardName;
    /**
     *级别
     */
    private String productLevel;
    /**
     *是否专营买断
     */
    private String isFranchise;
    /**
     *是否订单制
     */
    private String isOrderSystem;
    /**
     *名优普酒字段
     */
    private String famousValue;
    /**
     *度数
     */
    private String degrees;
    /**
     *冻结状态
     */
    private String frozenStatus;
    /**
     *日期
     */
    private Date createDate;
    /**
     *老商品编码
     */
    private List<TmProductSaleOldCodeVo> tmProductSaleOldCode;
    /**
     *基本关系转换
     */
    private List<ProductSaleConvertVo> tmProductSaleConvertEntities;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getProductSaleCode() {
        return productSaleCode;
    }

    public void setProductSaleCode(String productSaleCode) {
        this.productSaleCode = productSaleCode;
    }

    public String getMaterielName() {
        return materielName;
    }

    public void setMaterielName(String materielName) {
        this.materielName = materielName;
    }

    public String getSpartCode() {
        return spartCode;
    }

    public void setSpartCode(String spartCode) {
        this.spartCode = spartCode;
    }

    public String getSpartName() {
        return spartName;
    }

    public void setSpartName(String spartName) {
        this.spartName = spartName;
    }

    public String getBasicUnitCode() {
        return basicUnitCode;
    }

    public void setBasicUnitCode(String basicUnitCode) {
        this.basicUnitCode = basicUnitCode;
    }

    public String getBasicUnitName() {
        return basicUnitName;
    }

    public void setBasicUnitName(String basicUnitName) {
        this.basicUnitName = basicUnitName;
    }

    public String getProductTypeCode() {
        return productTypeCode;
    }

    public void setProductTypeCode(String productTypeCode) {
        this.productTypeCode = productTypeCode;
    }

    public String getProductTypeDesc() {
        return productTypeDesc;
    }

    public void setProductTypeDesc(String productTypeDesc) {
        this.productTypeDesc = productTypeDesc;
    }

    public String getProductBrandCode() {
        return productBrandCode;
    }

    public void setProductBrandCode(String productBrandCode) {
        this.productBrandCode = productBrandCode;
    }

    public String getProductBrandDesc() {
        return productBrandDesc;
    }

    public void setProductBrandDesc(String productBrandDesc) {
        this.productBrandDesc = productBrandDesc;
    }

    public String getSeriesCode() {
        return seriesCode;
    }

    public void setSeriesCode(String seriesCode) {
        this.seriesCode = seriesCode;
    }

    public String getSeriesDesc() {
        return seriesDesc;
    }

    public void setSeriesDesc(String seriesDesc) {
        this.seriesDesc = seriesDesc;
    }

    public String getBigLevelCode() {
        return bigLevelCode;
    }

    public void setBigLevelCode(String bigLevelCode) {
        this.bigLevelCode = bigLevelCode;
    }

    public String getBigLevelDesc() {
        return bigLevelDesc;
    }

    public void setBigLevelDesc(String bigLevelDesc) {
        this.bigLevelDesc = bigLevelDesc;
    }

    public String getSmallLevelCode() {
        return smallLevelCode;
    }

    public void setSmallLevelCode(String smallLevelCode) {
        this.smallLevelCode = smallLevelCode;
    }

    public String getSmallLevelDesc() {
        return smallLevelDesc;
    }

    public void setSmallLevelDesc(String smallLevelDesc) {
        this.smallLevelDesc = smallLevelDesc;
    }

    public String getChannel() {
        return channel;
    }

    public void setChannel(String channel) {
        this.channel = channel;
    }

    public String getChannelDesc() {
        return channelDesc;
    }

    public void setChannelDesc(String channelDesc) {
        this.channelDesc = channelDesc;
    }

    public Double getVolume() {
        return volume;
    }

    public void setVolume(Double volume) {
        this.volume = volume;
    }

    public String getVolumeUnitCode() {
        return volumeUnitCode;
    }

    public void setVolumeUnitCode(String volumeUnitCode) {
        this.volumeUnitCode = volumeUnitCode;
    }

    public String getVolumeUnitName() {
        return volumeUnitName;
    }

    public void setVolumeUnitName(String volumeUnitName) {
        this.volumeUnitName = volumeUnitName;
    }

    public String getProductSize() {
        return productSize;
    }

    public void setProductSize(String productSize) {
        this.productSize = productSize;
    }

    public String getProductExteriorCode() {
        return productExteriorCode;
    }

    public void setProductExteriorCode(String productExteriorCode) {
        this.productExteriorCode = productExteriorCode;
    }

    public String getProductExteriorName() {
        return productExteriorName;
    }

    public void setProductExteriorName(String productExteriorName) {
        this.productExteriorName = productExteriorName;
    }

    public String getSuitCode() {
        return suitCode;
    }

    public void setSuitCode(String suitCode) {
        this.suitCode = suitCode;
    }

    public String getSuitName() {
        return suitName;
    }

    public void setSuitName(String suitName) {
        this.suitName = suitName;
    }

    public String getExecutionStandardCode() {
        return executionStandardCode;
    }

    public void setExecutionStandardCode(String executionStandardCode) {
        this.executionStandardCode = executionStandardCode;
    }

    public String getExecutionStandardName() {
        return executionStandardName;
    }

    public void setExecutionStandardName(String executionStandardName) {
        this.executionStandardName = executionStandardName;
    }

    public String getProductLevel() {
        return productLevel;
    }

    public void setProductLevel(String productLevel) {
        this.productLevel = productLevel;
    }

    public String getIsFranchise() {
        return isFranchise;
    }

    public void setIsFranchise(String isFranchise) {
        this.isFranchise = isFranchise;
    }

    public String getIsOrderSystem() {
        return isOrderSystem;
    }

    public void setIsOrderSystem(String isOrderSystem) {
        this.isOrderSystem = isOrderSystem;
    }

    public String getFamousValue() {
        return famousValue;
    }

    public void setFamousValue(String famousValue) {
        this.famousValue = famousValue;
    }

    public String getDegrees() {
        return degrees;
    }

    public void setDegrees(String degrees) {
        this.degrees = degrees;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getFrozenStatus() {
        return frozenStatus;
    }

    public void setFrozenStatus(String frozenStatus) {
        this.frozenStatus = frozenStatus;
    }

    /**
     *基本关系转换
     */
    public List<ProductSaleConvertVo> getTmProductSaleConvertEntities() {
        return tmProductSaleConvertEntities;
    }

    /**
     *基本关系转换
     */
    public void setTmProductSaleConvertEntities(List<ProductSaleConvertVo> tmProductSaleConvertEntities) {
        this.tmProductSaleConvertEntities = tmProductSaleConvertEntities;
    }

    /**
     *老商品编码
     */
    public List<TmProductSaleOldCodeVo> getTmProductSaleOldCode() {
        return this.tmProductSaleOldCode;
    }

    /**
     *老商品编码
     */
    public void setTmProductSaleOldCode(List<TmProductSaleOldCodeVo> tmProductSaleOldCode) {
        this.tmProductSaleOldCode = tmProductSaleOldCode;
    }
}

==> mdm-rpc-0.1.105-sources.jar: com/chinayanghe/msp/mdm/vo/productSale/ProductSaleVo.java <==
package com.chinayanghe.msp.mdm.vo.productSale;


import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 商品信息实体类
 */

public class ProductSaleVo  implements Serializable {


    private static final long serialVersionUID = 679916831294067386L;
    private String id;


    /**
     *商品编码
     */
    private String productSaleCode;
    /**
     *物料名称
     */
    private String materielName;
    /**
     * 产品组编码
     */
    private String spartCode;
    /**
     * 产品组名称
     */
    private String spartName;
    /**
     *基本计量单位编码
     */
    private String basicUnitCode;
    /**
     *基本计量单位名称
     */
    private String basicUnitName;
    /**
     *品类编码
     */
    private String productTypeCode;
    /**
     *品类描述
     */
    private String productTypeDesc;
    /**
     *品牌编码
     */
    private String productBrandCode;
    /**
     *品牌描述
     */
    private String productBrandDesc;
    /**
     *系列编码
     */
    private String seriesCode;
    /**
     *系列描述
     */
    private String seriesDesc;
    /**
     *大类编码
     */
    private String bigLevelCode;
    /**
     *大类描述
     */
    private String bigLevelDesc;
    /**
     *小类编码
     */
    private String smallLevelCode;
    /**
     *小类描述
     */
    private String smallLevelDesc;
    /**
     *渠道编码
     */
    private String channel;
    /**
     *渠道描述
     */
    private String channelDesc;
    /**
     *体积
     */
    private Double volume;
    /**
     *体积单位编码
     */
    private String volumeUnitCode;
    /**
     *体积单位名称
     */
    private String volumeUnitName;
    /**
     *大小/量纲(规格)
     */
    private String productSize;
    /**
     *外观色系编码
     */
    private String productExteriorCode;
    /**
     *外观色系名称
     */
    private String productExteriorName;
    /**
     *套装编码
     */
    private String suitCode;
    /**
     *套装名称
     */
    private String suitName;
    /**
     *商品执行标准编码
     */
    private String executionStandardCode;
    /**
     *商品执行标准名称
     */
    private String executionStandardName;
    /**
     *级别
     */
    private String productLevel;
    /**
     *是否专营买断
     */
    private String isFranchise;
    /**
     *是否订单制
     */
    private String isOrderSystem;
    /**
     *名优普酒字段
     */
    private String famousValue;
    /**
     *度数
     */
    private String degrees;
    /**
     *冻结状态
     */
    private String frozenStatus;
    /**
     *日期
     */
    private Date createDate;
    /**
     * 跟新日期
     */
    private Date updateDate;
    /**
     *老商品编码
     */
    private List<TmProductSaleOldCodeVo> tmProductSaleOldCode;
    /**
     *基本关系转换
     */
    private List<ProductSaleConvertVo> tmProductSaleConvertEntities;

    public Date getUpdateDate() {
		return updateDate;
	}

	public void setUpdateDate(Date updateDate) {
		this.updateDate = updateDate;
	}

	public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getProductSaleCode() {
        return productSaleCode;
    }

    public void setProductSaleCode(String productSaleCode) {
        this.productSaleCode = productSaleCode;
    }

    public String getMaterielName() {
        return materielName;
    }

    public void setMaterielName(String materielName) {
        this.materielName = materielName;
    }

    public String getSpartCode() {
        return spartCode;
    }

    public void setSpartCode(String spartCode) {
        this.spartCode = spartCode;
    }

    public String getSpartName() {
        return spartName;
    }

    public void setSpartName(String spartName) {
        this.spartName = spartName;
    }

    public String getBasicUnitCode() {
        return basicUnitCode;
    }

    public void setBasicUnitCode(String basicUnitCode) {
        this.basicUnitCode = basicUnitCode;
    }

    public String getBasicUnitName() {
        return basicUnitName;
    }

    public void setBasicUnitName(String basicUnitName) {
        this.basicUnitName = basicUnitName;
    }

    public String getProductTypeCode() {
        return productTypeCode;
    }

    public void setProductTypeCode(String productTypeCode) {
        this.productTypeCode = productTypeCode;
    }

    public String getProductTypeDesc() {
        return productTypeDesc;
    }

    public void setProductTypeDesc(String productTypeDesc) {
        this.productTypeDesc = productTypeDesc;
    }

    public String getProductBrandCode() {
        return productBrandCode;
    }

    public void setProductBrandCode(String productBrandCode) {
        this.productBrandCode = productBrandCode;
    }

    public String getProductBrandDesc() {
        return productBrandDesc;
    }

    public void setProductBrandDesc(String productBrandDesc) {
        this.productBrandDesc = productBrandDesc;
    }

    public String getSeriesCode() {
        return seriesCode;
    }

    public void setSeriesCode(String seriesCode) {
        this.seriesCode = seriesCode;
    }

    public String getSeriesDesc() {
        return seriesDesc;
    }

    public void setSeriesDesc(String seriesDesc) {
        this.seriesDesc = seriesDesc;
    }

    public String getBigLevelCode() {
        return bigLevelCode;
    }

    public void setBigLevelCode(String bigLevelCode) {
        this.bigLevelCode = bigLevelCode;
    }

    public String getBigLevelDesc() {
        return bigLevelDesc;
    }

    public void setBigLevelDesc(String bigLevelDesc) {
        this.bigLevelDesc = bigLevelDesc;
    }

    public String getSmallLevelCode() {
        return smallLevelCode;
    }

    public void setSmallLevelCode(String smallLevelCode) {
        this.smallLevelCode = smallLevelCode;
    }

    public String getSmallLevelDesc() {
        return smallLevelDesc;
    }

    public void setSmallLevelDesc(String smallLevelDesc) {
        this.smallLevelDesc = smallLevelDesc;
    }

    public String getChannel() {
        return channel;
    }

    public void setChannel(String channel) {
        this.channel = channel;
    }

    public String getChannelDesc() {
        return channelDesc;
    }

    public void setChannelDesc(String channelDesc) {
        this.channelDesc = channelDesc;
    }

    public Double getVolume() {
        return volume;
    }

    public void setVolume(Double volume) {
        this.volume = volume;
    }

    public String getVolumeUnitCode() {
        return volumeUnitCode;
    }

    public void setVolumeUnitCode(String volumeUnitCode) {
        this.volumeUnitCode = volumeUnitCode;
    }

    public String getVolumeUnitName() {
        return volumeUnitName;
    }

    public void setVolumeUnitName(String volumeUnitName) {
        this.volumeUnitName = volumeUnitName;
    }

    public String getProductSize() {
        return productSize;
    }

    public void setProductSize(String productSize) {
        this.productSize = productSize;
    }

    public String getProductExteriorCode() {
        return productExteriorCode;
    }

    public void setProductExteriorCode(String productExteriorCode) {
        this.productExteriorCode = productExteriorCode;
    }

    public String getProductExteriorName() {
        return productExteriorName;
    }

    public void setProductExteriorName(String productExteriorName) {
        this.productExteriorName = productExteriorName;
    }

    public String getSuitCode() {
        return suitCode;
    }

    public void setSuitCode(String suitCode) {
        this.suitCode = suitCode;
    }

    public String getSuitName() {
        return suitName;
    }

    public void setSuitName(String suitName) {
        this.suitName = suitName;
    }

    public String getExecutionStandardCode() {
        return executionStandardCode;
    }

    public void setExecutionStandardCode(String executionStandardCode) {
        this.executionStandardCode = executionStandardCode;
    }

    public String getExecutionStandardName() {
        return executionStandardName;
    }

    public void setExecutionStandardName(String executionStandardName) {
        this.executionStandardName = executionStandardName;
    }

    public String getProductLevel() {
        return productLevel;
    }

    public void setProductLevel(String productLevel) {
        this.productLevel = productLevel;
    }

    public String getIsFranchise() {
        return isFranchise;
    }

    public void setIsFranchise(String isFranchise) {
        this.isFranchise = isFranchise;
    }

    public String getIsOrderSystem() {
        return isOrderSystem;
    }

    public void setIsOrderSystem(String isOrderSystem) {
        this.isOrderSystem = isOrderSystem;
    }

    public String getFamousValue() {
        return famousValue;
    }

    public void setFamousValue(String famousValue) {
        this.famousValue = famousValue;
    }

    public String getDegrees() {
        return degrees;
    }

    public void setDegrees(String degrees) {
        this.degrees = degrees;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getFrozenStatus() {
        return frozenStatus;
    }

    public void setFrozenStatus(String frozenStatus) {
        this.frozenStatus = frozenStatus;
    }

    /**
     *基本关系转换
     */
    public List<ProductSaleConvertVo> getTmProductSaleConvertEntities() {
        return tmProductSaleConvertEntities;
    }

    /**
     *基本关系转换
     */
    public void setTmProductSaleConvertEntities(List<ProductSaleConvertVo> tmProductSaleConvertEntities) {
        this.tmProductSaleConvertEntities = tmProductSaleConvertEntities;
    }

    /**
     *老商品编码
     */
    public List<TmProductSaleOldCodeVo> getTmProductSaleOldCode() {
        return this.tmProductSaleOldCode;
    }

    /**
     *老商品编码
     */
    public void setTmProductSaleOldCode(List<TmProductSaleOldCodeVo> tmProductSaleOldCode) {
        this.tmProductSaleOldCode = tmProductSaleOldCode;
    }
}
